#[repr(u8)]pub enum ClientStatus {
Connecting,
Connected(ConnectionType),
Stalled,
Disconnected(DisconnectionType),
}Expand description
Represents the current status of the LightstreamerClient.
Variants
Connecting
The client is attempting to connect to the Lightstreamer Server.
Connected(ConnectionType)
The client has successfully connected to the Lightstreamer Server. Contains the type of connection established.
Stalled
The connection has been temporarily interrupted. The client will automatically try to recover the connection.
Disconnected(DisconnectionType)
The client is disconnected from the Lightstreamer Server. Contains information about the disconnection type.