Transport

Enum Transport 

#[repr(u8)]
pub enum Transport { Ws = 0, Http = 1, WsStreaming = 2, HttpStreaming = 3, WsPolling = 4, HttpPolling = 5, }
The transport type to be used by the client.

  • WS: the Stream-Sense algorithm is enabled as in the None case but the client will only use WebSocket based connections. If a connection over WebSocket is not possible because of the environment the client will not connect at all.
  • HTTP: the Stream-Sense algorithm is enabled as in the None case but the client will only use HTTP based connections. If a connection over HTTP is not possible because of the environment the client will not connect at all.
  • WS-STREAMING: the Stream-Sense algorithm is disabled and the client will only connect on Streaming over WebSocket. If Streaming over WebSocket is not possible because of the environment the client will not connect at all.
  • HTTP-STREAMING: the Stream-Sense algorithm is disabled and the client will only connect on Streaming over HTTP. If Streaming over HTTP is not possible because of the browser/environment the client will not connect at all.
  • WS-POLLING: the Stream-Sense algorithm is disabled and the client will only connect on Polling over WebSocket. If Polling over WebSocket is not possible because of the environment the client will not connect at all.
  • HTTP-POLLING: the Stream-Sense algorithm is disabled and the client will only connect on Polling over HTTP. If Polling over HTTP is not possible because of the environment the client will not connect at all.

Variants



Ws = 0

WebSocket transport with Stream-Sense algorithm enabled. The client will only use WebSocket-based connections.



Http = 1

HTTP transport with Stream-Sense algorithm enabled. The client will only use HTTP-based connections.



WsStreaming = 2

WebSocket Streaming transport with Stream-Sense algorithm disabled. The client will only connect on Streaming over WebSocket.



HttpStreaming = 3

HTTP Streaming transport with Stream-Sense algorithm disabled. The client will only connect on Streaming over HTTP.



WsPolling = 4

WebSocket Polling transport with Stream-Sense algorithm disabled. The client will only connect on Polling over WebSocket.



HttpPolling = 5

HTTP Polling transport with Stream-Sense algorithm disabled. The client will only connect on Polling over HTTP.