#[non_exhaustive]pub struct MessageOutcome {
pub sequence: Option<String>,
pub progressive: Option<u64>,
pub result: MessageResult,
}Expand description
The report of one message’s fate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sequence: Option<String>The sequence the message was sent in, or None when it was sent in
none.
progressive: Option<u64>The progressive that identifies the message, or None for a
fire-and-forget one — which can only ever be reported as
MessageResult::NotSent or MessageResult::Refused.
result: MessageResultWhat became of it.
Implementations
Sourceimpl MessageOutcome
impl MessageOutcome
Sourcepub const fn is_delivered(&self) -> bool
pub const fn is_delivered(&self) -> bool
Whether the Metadata Adapter processed the message.