#[repr(u8)]pub enum SubscriptionMode {
Merge = 0,
Distinct = 1,
Raw = 2,
Command = 3,
}Expand description
Enum representing the subscription mode.
Variants
Merge = 0
MERGE mode. The server sends an update for a specific item only if the state of at least one of the fields has changed.
Distinct = 1
DISTINCT mode. The server sends an update for an item every time new data for that item is available.
Raw = 2
RAW mode. The server forwards any update for an item that it receives, without performing any processing.
Command = 3
COMMAND mode. The server sends updates based on add, update, and delete commands.